@@ -32,6 +32,13 @@ public:
     //get/set font
     QFont getFont() const;
     void setFont(const QFont &aFont) const;
+    //get/set blinking
+    bool getBlinking() const;
+    void setBlinking(const bool &aBlink) const;
+    //get/set time zone
+    int getTZoffset() const;
+    void setTZoffset(const int &aOffset) const;
+
 
 private:
     dclocksettings() {}
