@@ -10,7 +10,7 @@ class DigitalClockWdg : public QWidget
     Q_OBJECT
 
 signals:
-    void updateClock();
+    void updateClock(QString);
 
 public slots:
     void showSettingsDialog();
@@ -19,12 +19,18 @@ public slots:
 public:
     DigitalClockWdg(QWidget *parent = 0);
 
+protected:
+    void mouseReleaseEvent ( QMouseEvent * e );
+    void mousePressEvent ( QMouseEvent * e );
+
 private slots:
     void showTime();
 
 private:
     void loadSettings();
     void initClock();
+    void showClock();
+    QTime calcTime();
 
 private:
     QWidget * clk1;
@@ -36,6 +42,11 @@ private:
     QSize m_size;
     int m_timer_tick;
     QString m_timeFormat;
+    bool m_mouseClick;
+    QPoint m_lastPoint;
+    int m_blinking1;
+    int m_blinking2;
+    int m_tzOffset;
 };
 
 #endif
