@@ -29,10 +29,13 @@ private slots:
 private:
     void loadSettings();
     void buildFontList();
+    void fillCbTZ();
+    int calcOffset() const;
 
 private:
     Ui::SettingsDialog *ui;
     QFont m_font;
+//    int m_defTZoffset;
 };
 
 #endif // SETTINGSDIALOG_H
