@@ -1,5 +1,6 @@
 #include <QtGui>
 #include <QLocale>
+#include <QtDBus/QtDBus>
 
 #include "digitalclockwdg.h"
 #include "settingsdialog.h"
@@ -11,26 +12,13 @@ DigitalClockWdg::DigitalClockWdg(QWidget *parent)
     : QWidget(parent)
 {
 
-    QTimer *timer = new QTimer(this);
-    connect(timer, SIGNAL(timeout()), this, SLOT(showTime()));
-//    timer->start(10000);
     setWindowTitle(tr("Digital Clock"));
     resize(150, 60);
-//    lcd = false;
+//    setWindowOpacity();
     setAttribute(Qt::WA_TranslucentBackground);
-
-//    m_timeFormat = QString(" hh:mm:ss ap");
-//    m_digitColor = QColor(Qt::green);
-//    m_font.setFamily("Helvetica");
-//    m_font.setBold(true);
-
     clk1 = new QWidget(this);
-
     m_timer = new QTimer(this);
     connect(m_timer, SIGNAL(timeout()), this, SLOT(showTime()));
-
-//    showSettingsDialog();
-
     loadSettings();
     initClock();
 }
@@ -38,41 +26,57 @@ DigitalClockWdg::DigitalClockWdg(QWidget *parent)
 void DigitalClockWdg::initClock()
 {
     delete clk1;
+    QTime tm = calcTime();
+    QString tStr = tm.toString(m_timeFormat);
     if (m_lcd)
     {
-        clk1 = new LcdClock(m_digitColor, m_timeFormat, this);
-        connect(this,SIGNAL(updateClock()),clk1,SLOT(showTime()));
+//        clk1 = new LcdClock(m_digitColor, m_timeFormat, m_blinking1, m_blinking2, this);
+        clk1 = new LcdClock(m_digitColor, tStr, this);
+        connect(this,SIGNAL(updateClock(QString)),clk1,SLOT(showTime(QString)));
         clk1->show();
 //        m_lcd = false;
     }
     else
     {
-        clk1 = new FontClock(m_digitColor, m_timeFormat, m_font, this);
-        connect(this,SIGNAL(updateClock()),clk1,SLOT(showTime()));
+//        clk1 = new FontClock(m_digitColor, m_timeFormat, m_font, m_blinking1, m_blinking2, this);
+        clk1 = new FontClock(m_digitColor, m_font, tStr, this);
+        connect(this,SIGNAL(updateClock(QString)),clk1,SLOT(showTime(QString)));
         clk1->show();
 //        lcd = true;
     }
 }
 
+QTime DigitalClockWdg::calcTime()
+{
+    if (m_tzOffset == -50000)
+        return QTime::currentTime();
+    else
+    {
+        QDateTime dt = QDateTime::currentDateTime();
+        QDateTime udt = dt.toUTC();
+        dt = udt.addSecs(m_tzOffset);
+        return dt.time();
+    }
+}
+
 void DigitalClockWdg::showTime()
 {
     //TODO update clock
-    emit updateClock();
+    QTime tt = calcTime();
+
 //    QTime time = QTime::currentTime();
-//    QString text;
-
-//    QLocale cLoc (QLocale::English, QLocale::UnitedStates);
-//    QString tf = cLoc.timeFormat();
-//    text = time.toString(Qt::DefaultLocaleLongDate);
-//    text = cLoc.toString(time, tf);
-
-//    if (m_showSeconds)
-//        text = time.toString("hh:mm:ss");
-//        text = time.toString(m_timeFormat);
-//    else
-  //      text = time.toString("hhmmss");
-  //      text = time.toString("hh:mm");
-//    display(text);
+    QString text = tt.toString(m_timeFormat);
+    if (m_blinking1)
+    {
+        int lngt = text.length();
+        if ((tt.second() % 2) == 0)
+        {
+            text[lngt-m_blinking1] = ' ';
+            if (m_blinking2)
+                text[lngt-m_blinking2] = ' ';
+        }
+    }
+    emit updateClock(text);
 }
 
 void DigitalClockWdg::showSettingsDialog()
@@ -91,6 +95,9 @@ void DigitalClockWdg::loadSettings()
     bool showSeconds = dclocksettings::getInstance().getShowSeconds();
     int timeFormatIdx = dclocksettings::getInstance().getTimeFormat();
     m_size = dclocksettings::getInstance().getSize();
+    bool blinking = dclocksettings::getInstance().getBlinking();
+    m_blinking1 = 0;
+    m_blinking2 = 0;
 
 //    QString timeFormat;
     if (showSeconds)
@@ -98,43 +105,55 @@ void DigitalClockWdg::loadSettings()
         {
             case 1:     // 12 H (AM/PM)
                 m_timeFormat = QString(" h:mm:ss ap");
+                if (blinking)
+                {
+                    m_blinking1 = 6;
+                    m_blinking2 = 9;
+                }
                 break;
             case 2:     // mmilitary
                 m_timeFormat = QString("HHmmss");
                 break;
             default:    // 24 H
                 m_timeFormat = QString("HH:mm:ss");
+                if (blinking)
+                {
+                    m_blinking1 = 3;
+                    m_blinking2 = 6;
+                }
             }
     else
         switch (timeFormatIdx)
         {
             case 1:     // 12 H (AM/PM)
                 m_timeFormat = QString(" h:mm ap");
+                if (blinking)
+                {
+                    m_blinking1 = 6;
+                }
                 break;
             case 2:     // mmilitary
                 m_timeFormat = QString("HHmm");
                 break;
             default:    // 24 H
                 m_timeFormat = QString("HH:mm");
-        }
+                if (blinking)
+                {
+                    m_blinking1 = 3;
+                }
 
-//    setDigitCount(m_timeFormat.length());
+        }
 
     m_lcd = dclocksettings::getInstance().getLcd();
     m_font = dclocksettings::getInstance().getFont();
+    m_tzOffset = dclocksettings::getInstance().getTZoffset();
 
     m_timer->stop();
-//    m_timer->start(m_timer_tick);
     m_timer->start(1000);
-/*    QPalette qp;
-    qp.setColor(QPalette::WindowText,m_digitColor );
-    qp.setColor(QPalette::Window,Qt::transparent );
-    setPalette(qp);*/
     int x = geometry().x();
     int y = geometry().y();
     setGeometry(x,y,m_size.width(),m_size.height());
     initClock();
-    //resize(m_size);
 }
 
 void DigitalClockWdg::homeScreenChanged(bool isOnCurrentHomescreen)
@@ -150,3 +169,34 @@ void DigitalClockWdg::homeScreenChanged(bool isOnCurrentHomescreen)
         m_timer->stop();
 }
 
+
+void DigitalClockWdg::mouseReleaseEvent ( QMouseEvent * e )
+{
+    Q_UNUSED(e);
+    //test Dialogs
+    if ((m_mouseClick) && (e->pos() == m_lastPoint) )
+    {
+        showClock();
+    }
+}
+
+void DigitalClockWdg::mousePressEvent ( QMouseEvent * e )
+{
+//    Q_UNUSED(e);
+    m_lastPoint = e->pos();
+    m_mouseClick = true;
+}
+/*
+void DigitalClockWdg::mouseMoveEvent ( QMouseEvent * e )
+{
+    Q_UNUSED(e);
+    m_mouseClick = false;
+}
+*/
+void DigitalClockWdg::showClock()
+{
+    QDBusConnection bus = QDBusConnection::sessionBus();
+    QDBusInterface dbus_iface("com.nokia.HildonDesktop.AppMgr", "/com/nokia/HildonDesktop/AppMgr",
+                          "com.nokia.HildonDesktop.AppMgr", bus);
+    dbus_iface.call("LaunchApplication","worldclock");
+}
