@@ -1,14 +1,16 @@
 #include <QtGui>
 #include "fontclock.h"
 
-FontClock::FontClock(QColor &aColor, QString &aFormat, QFont &aFont, QWidget *parent) :
-    QWidget(parent), m_font(aFont), m_color(aColor), m_format(aFormat)
+//FontClock::FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent) :
+//    QWidget(parent), m_font(aFont), m_color(aColor), m_format(aFormat), m_blink1(aBlink1), m_blink2(aBlink2)
+FontClock::FontClock(QColor &aColor, QFont &aFont, QString &aTime, QWidget *parent) :
+    QWidget(parent), m_font(aFont), m_color(aColor), m_text(aTime)
 {
     QSize aa = parent->size();
     resize(aa);
     setAttribute(Qt::WA_TranslucentBackground);
     calcFontSize();
-    showTime();
+    showTime(m_text);
 }
 
 void FontClock::calcFontSize()
@@ -16,8 +18,8 @@ void FontClock::calcFontSize()
     int wd_width = size().width();
     int wd_hgt = size().height();
 
-    QTime time = QTime::currentTime();
-    m_text = time.toString(m_format);
+//    QTime time = QTime::currentTime();
+//    m_text = time.toString(m_format);
 
     QString fFamily = m_font.family();
     // calc font size
@@ -38,10 +40,21 @@ void FontClock::calcFontSize()
     m_font.setPointSize(m_fntSize);
 }
 
-void FontClock::showTime()
+void FontClock::showTime(QString aTime)
 {
-    QTime time = QTime::currentTime();
+/*    QTime time = QTime::currentTime();
     m_text = time.toString(m_format);
+    if (m_blink1)
+    {
+        int lngt = m_text.length();
+        if ((time.second() % 2) == 0)
+        {
+            m_text[lngt-m_blink1] = ' ';
+            if (m_blink2)
+                m_text[lngt-m_blink2] = ' ';
+        }
+    }*/
+    m_text = aTime;
     update();
 }
 
