@@ -8,10 +8,11 @@ class FontClock : public QWidget
 {
     Q_OBJECT
 public:
-    explicit FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent = 0);
+//    explicit FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent = 0);
+    explicit FontClock(QColor &aColor, QFont &aFont, QString &aTime, QWidget *parent = 0);
 
 public slots:
-    void showTime();
+    void showTime(QString aTime);
 
 private:
 //    void showTime();
@@ -21,13 +22,13 @@ protected:
     void paintEvent(QPaintEvent *event);
 
 private:
-    QString m_text;
     int m_fntSize;
     QFont m_font;
     QColor m_color;
-    QString m_format;
-    int m_blink1;
-    int m_blink2;
+    QString m_text;
+//    QString m_format;
+//    int m_blink1;
+//    int m_blink2;
 
 };
 
